<?php 
	/*session_start();*/
	include_once '../../model/conexion.php';

	class Grupo_model{
		private $param = array();
	    private $con;

	    public function __construct(){
	    	$this->con = new Conexion();
	    }	


	    public function gestionar($param){
	    	$this->param = $param;
	    	switch ($this->param['param_opcion'])
			{
				case 'mostrarGrupos':
					echo $this->mostrarGrupos();
					break;	
				case 'insert':
					echo $this->insert();
					break;	
				case 'obtener':
					echo $this->obtener();
					break;
				case 'update':
					echo $this->update();
					break;		
				case 'eliminar':
					echo $this->eliminar();
					break;	
			}
	    }	

	    private function mostrarGrupos(){
			$this->con->cerrarAbrir();
			$sql = "call sp_mostrarGrupos(";
			$sql .= "1,";
	    	$sql .= "1)";

	    	$tabla = "";
	    	$cont = 0;
			$datos = $this->con->consultaRetorno($sql);           
           	while($fila = mysqli_fetch_array($datos)){
           		$cont = $cont + 1;
            	$tabla .= "<tr>";
                    $tabla .= "<td class='alinearCentro'>".$cont."</td>";
                    $tabla .= "<td class='alinearIzquierda'>".$fila["nombre"]."</td>";
                    $tabla .= "<td class='alinearIzquierda'>".$fila["descripcion"]."</td>";
                    $tabla .= "<td class='alinearCentro'>".$fila["activo"]."</td>";
                    $tabla .= "<th class='alinearCentro'>
                    			<a href='#modalUpdate' data-toggle='modal' class='btn btn-success btn-xs' onclick='obtener(".$fila["idGrupo"].")'><i class='fa fa-pencil'></i>  </a>

                    			<a href='#modalEliminar' data-toggle='modal' class='btn btn-danger btn-xs' onclick='obtenerId(".$fila["idGrupo"].")'><i class='fa fa-trash-o'></i> </a>
                    			</th>";
                $tabla .= "</tr>";
            }      
        	return $tabla;
		}

	    private function insert(){
	    	$this->con->cerrarAbrir();
			$sql = "call sp_insertUpdateGrupos(";
			$sql .= "1, ";
			$sql .= "'".$this->param['param_nombre']."', ";
			$sql .= "'".$this->param['param_descripcion']."', ";
			$sql .= "'-', ";
			$sql .= "6, ";
			$sql .= "'".$_SESSION['usuario']."',";
			$sql .= "'".$_SESSION['usuario']."',";
			$sql .= "1,";
			$sql .= "1) ";
			

	    	$datos = $this->con->consultaRetorno($sql);
	    	while ($fila = mysqli_fetch_array($datos)) {
            	$respuesta = $fila['respuesta'];
        	}

        	return $respuesta;
	    }

	    private function obtener(){
			$this->con->cerrarAbrir();
			$sql = "call sp_mostrarGrupos(";
			$sql .= "".$this->param['param_idGrupo'].", ";
	    	$sql .= "3)";

			$datos = $this->con->consultaRetorno($sql);           
           	while($fila = mysqli_fetch_array($datos)){
            	return json_encode($fila);
            }      
		}

	    private function update(){
	    	$this->con->cerrarAbrir();
			$sql = "call sp_insertUpdateGrupos(";
			$sql .= "".$this->param['param_idGrupo'].", ";
			$sql .= "'".$this->param['param_nombre']."', ";
			$sql .= "'".$this->param['param_descripcion']."', ";
			$sql .= "'-', ";
			$sql .= "6, ";
			$sql .= "'".$_SESSION['usuario']."',";
			$sql .= "'".$_SESSION['usuario']."',";
			$sql .= "".$this->param['param_activo'].", ";
			$sql .= "2) ";
			

	    	$datos = $this->con->consultaRetorno($sql);
	    	while ($fila = mysqli_fetch_array($datos)) {
            	$respuesta = $fila['respuesta'];
        	}

        	return $respuesta;
	    }	   

	    private function eliminar(){
			$this->con->cerrarAbrir();
			$sql = "call sp_eliminarGrupo(";
			$sql .= "".$this->param['param_idGrupo'].", ";
	    	$sql .= "1)";

			$this->con->consultaSimple($sql);  

        	return 1;
		}      		
	}
?>